"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createResolvers = void 0;
const relay_1 = require("../relay");
const repositories_1 = require("./repositories");
const assert_ts_1 = require("assert-ts");
function createResolvers({ users, githubRepositories, githubOrganizations, }) {
    return {
        Query: {
            viewer(_, { size, cursor }) {
                let orgs = [...users]
                    .flatMap(e => { var _a; return (_a = e.githubAccount) === null || _a === void 0 ? void 0 : _a.organizations; })
                    .flatMap(org => (!!org ? [org] : []));
                return {
                    organizations: (0, relay_1.applyRelayPagination)(orgs, { first: size, after: cursor }, node => {
                        return {
                            ...node,
                            teams: (0, relay_1.applyRelayPagination)(node.teams, { first: 10 }, team => {
                                return {
                                    ...team,
                                };
                            }),
                        };
                    }),
                };
            },
            organization(_, { login }) {
                let [org] = [...githubOrganizations].filter(o => o.login === login);
                (0, assert_ts_1.assert)(!!org, `no orginization found for ${login}`);
                // TODO: why do we have commits with the repos?
                let organizationRepositories = org.repositories.filter(repo => !!repo.owner);
                return {
                    ...org,
                    repositories(pageArgs) {
                        return (0, repositories_1.requestRepositories)(organizationRepositories, pageArgs);
                    },
                };
            },
            organizations(pageArgs) {
                let orgs = [...githubOrganizations];
                return (0, relay_1.applyRelayPagination)(orgs, pageArgs, org => {
                    return {
                        ...org,
                        repositories(repositoryiesPageArgs) {
                            return (0, repositories_1.requestRepositories)(org.repositories, repositoryiesPageArgs);
                        },
                    };
                });
            },
            repository(_, { owner, name }) {
                let repo = [...githubRepositories].find((r) => r.name.toLowerCase() === name &&
                    r.nameWithOwner.toLowerCase() === `${owner}/${name}`.toLowerCase());
                (0, assert_ts_1.assert)(!!repo, `no repository found for ${name}`);
                return {
                    // id: repo.id,
                    name: repo.name,
                    nameWithOwner: repo.nameWithOwner,
                    url: repo.url,
                    description: repo.description,
                    visibility: repo.visibility,
                    languages: {
                        nodes: repo.languages.map(l => ({
                            name: l,
                        })),
                    },
                    repositoryTopics: {
                        nodes: repo.repositoryTopics.map(t => ({
                            topic: { name: t },
                        })),
                    },
                    owner: {
                        __typename: 'teams' in repo.owner ? 'Organization' : 'User',
                        name: repo.owner.name,
                        login: repo.owner.login,
                    },
                    // collaborators(pageArgs: PageArgs) {
                    //   return applyRelayPagination(repo.collaborators, pageArgs);
                    // },
                };
            },
        },
    };
}
exports.createResolvers = createResolvers;
//# sourceMappingURL=resolvers.js.map